.. Camelot documentation master file, created by
   sphinx-quickstart on Thu Jun 11 21:14:38 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _camelotdoc-index:

Welcome to Camelot's documentation!
===================================

:Release: |version|
:Date: |today|

Contents:

.. toctree::
   :maxdepth: 2

   tutorial/index.rst
   doc/index.rst

Indices and tables:

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Others:

.. toctree::
   :maxdepth: 2

   Complete Table of Contents <contents.rst>
   glossary.rst
   license.rst
   copyright.rst
